"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .imageurl import ImageURL, ImageURLTypedDict
from mistralai.types import BaseModel
from typing import Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


ImageURLChunkImageURLTypedDict = TypeAliasType(
    "ImageURLChunkImageURLTypedDict", Union[ImageURLTypedDict, str]
)


ImageURLChunkImageURL = TypeAliasType("ImageURLChunkImageURL", Union[ImageURL, str])


ImageURLChunkType = Literal["image_url"]


class ImageURLChunkTypedDict(TypedDict):
    r"""{\"type\":\"image_url\",\"image_url\":{\"url\":\"data:image/png;base64,iVBORw0"""

    image_url: ImageURLChunkImageURLTypedDict
    type: NotRequired[ImageURLChunkType]


class ImageURLChunk(BaseModel):
    r"""{\"type\":\"image_url\",\"image_url\":{\"url\":\"data:image/png;base64,iVBORw0"""

    image_url: ImageURLChunkImageURL

    type: Optional[ImageURLChunkType] = "image_url"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
from mistralai.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class FilesAPIRoutesGetSignedURLRequestTypedDict(TypedDict):
    file_id: str
    expiry: NotRequired[int]
    r"""Number of hours before the url becomes invalid. Defaults to 24h"""


class FilesAPIRoutesGetSignedURLRequest(BaseModel):
    file_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    expiry: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 24
    r"""Number of hours before the url becomes invalid. Defaults to 24h"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
from typing import List, Literal, Optional
from typing_extensions import NotRequired, TypedDict


ReferenceChunkType = Literal["reference"]


class ReferenceChunkTypedDict(TypedDict):
    reference_ids: List[int]
    type: NotRequired[ReferenceChunkType]


class ReferenceChunk(BaseModel):
    reference_ids: List[int]

    type: Optional[ReferenceChunkType] = "reference"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .jobout import JobOut, JobOutTypedDict
from .legacyjobmetadataout import LegacyJobMetadataOut, LegacyJobMetadataOutTypedDict
from typing import Union
from typing_extensions import TypeAliasType


JobsAPIRoutesFineTuningCreateFineTuningJobResponseTypedDict = TypeAliasType(
    "JobsAPIRoutesFineTuningCreateFineTuningJobResponseTypedDict",
    Union[LegacyJobMetadataOutTypedDict, JobOutTypedDict],
)
r"""OK"""


JobsAPIRoutesFineTuningCreateFineTuningJobResponse = TypeAliasType(
    "JobsAPIRoutesFineTuningCreateFineTuningJobResponse",
    Union[LegacyJobMetadataOut, JobOut],
)
r"""OK"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from mistralai.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


GithubRepositoryInType = Literal["github"]


class GithubRepositoryInTypedDict(TypedDict):
    name: str
    owner: str
    token: str
    type: GithubRepositoryInType
    ref: NotRequired[Nullable[str]]
    weight: NotRequired[float]


class GithubRepositoryIn(BaseModel):
    name: str

    owner: str

    token: str

    TYPE: Annotated[
        Annotated[
            Optional[GithubRepositoryInType], AfterValidator(validate_const("github"))
        ],
        pydantic.Field(alias="type"),
    ] = "github"

    ref: OptionalNullable[str] = UNSET

    weight: Optional[float] = 1

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["type", "ref", "weight"]
        nullable_fields = ["ref"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
